@@ -19,11 +19,17 @@ EL_digraph <- list(
 oldopt <- getOption("diffnet.undirected")
 options(diffnet.undirected=FALSE)
 
+# Function to create diffnet_degSeq, matrix
+asdegseq <- function(x) {
+  structure(cbind(x), class=c("diffnet_degSeq", "matrix"))
+}
+
 for (i in names(EL_digraph)) {
   test_that(paste0("indegree of directed graph - ",i), {
-    expect_equivalent(dgr(EL_digraph[[i]], "indegree"), cbind(c(2,2,0)))
-    expect_equivalent(dgr(EL_digraph[[i]], "outdegree"), cbind(c(1,1,2)))
-    expect_equivalent(dgr(EL_digraph[[i]], "degree"), cbind(c(3,3,2)))
+
+    expect_equivalent(dgr(EL_digraph[[i]], "indegree"), asdegseq(c(2,2,0)))
+    expect_equivalent(dgr(EL_digraph[[i]], "outdegree"), asdegseq(c(1,1,2)))
+    expect_equivalent(dgr(EL_digraph[[i]], "degree"), asdegseq(c(3,3,2)))
   }
   )
 }
@@ -43,9 +49,9 @@ EL_digraph <- list(`matrix` = graph, `dgCMatrix` = as(graph, "dgCMatrix"))
 
 for (i in names(EL_digraph)) {
   test_that(paste0("Degree of undirected graph - ",i), {
-    expect_equivalent(dgr(EL_digraph[[i]], "indegree"), cbind(c(2,2,2)))
-    expect_equivalent(dgr(EL_digraph[[i]], "outdegree"), cbind(c(2,2,2)))
-    expect_equivalent(dgr(EL_digraph[[i]], "degree"), cbind(c(2,2,2)))
+    expect_equivalent(dgr(EL_digraph[[i]], "indegree"), asdegseq(c(2,2,2)))
+    expect_equivalent(dgr(EL_digraph[[i]], "outdegree"), asdegseq(c(2,2,2)))
+    expect_equivalent(dgr(EL_digraph[[i]], "degree"), asdegseq(c(2,2,2)))
   }
   )
 }
@@ -109,3 +115,19 @@ test_that("Either as an array or as a list, dgr should work (directed)", {
 })
 
 options(diffnet.undirected=oldopt)
+
+# igraph and statnet -----------------------------------------------------------
+test_that("dgr on igraph and statnet", {
+  set.seed(1313)
+  g <- rgraph_ba(t=9, m=2, self=FALSE)
+
+  ans0 <- dgr(g)
+  ans1 <- suppressWarnings(dgr(igraph::graph_from_adjacency_matrix(g)))
+  ans2 <- dgr(network::network(as.matrix(g)))
+
+  expect_equal(ans0,ans1)
+  expect_equal(ans0,ans2)
+
+  expect_silent(plot(ans0))
+
+})
